@@ -131,6 +131,8 @@ xmldataentity(XMLParser *x, const char *d, size_t dl)
 void
 xmltagend(XMLParser *x, const char *t, size_t tl, int isshort)
 {
+	char *p;
+
 	if (!isresult)
 		return;
 
@@ -148,9 +150,9 @@ xmltagend(XMLParser *x, const char *t, size_t tl, int isshort)
 		isurl = 0;
 	if (!strcmp(t, "div")) {
 		/* decode url and remove "tracking"/usage part via DDG */
-		if (!strncmp(result.url, "uddg=", sizeof("uddg=") - 1)) {
-			if (decodeparam(result.urldecoded, sizeof(result.urldecoded),
-			    result.url + sizeof("uddg=") - 1) == -1)
+		if ((p = strstr(result.url, "uddg="))) {
+			p += sizeof("uddg=") - 1;
+			if (decodeparam(result.urldecoded, sizeof(result.urldecoded), p) == -1)
 				result.urldecoded[0] = '\0';
 		}
 
